=============
API reference
=============

This page gives an overview of all public polars objects, functions and
methods. All classes and functions exposed in ``polars.*`` namespace are public.

.. toctree::
   :maxdepth: 2

   io
   series/index
   dataframe/index
   lazyframe/index
   expressions/index
   selectors
   api
   functions
   datatypes
   config
   exceptions
   testing
   utils
   sql
